@@ -40,6 +40,14 @@ class AntiSpam(object):
     """Stores tweets with timestamps to prevent some spam."""
 
     tweet_store = {}
+    timeout = 600
+
+    def __init__(self, timeout=None):
+        """Possible to override the timeout, for testing purposes."""
+
+        if timeout and isinstance(timeout, int):
+            setattr(AntiSpam, "timeout", timeout)
+        super(AntiSpam, self).__init__()
 
     @staticmethod
     def is_spam(tweet_text):
@@ -62,7 +70,7 @@ class AntiSpam(object):
 
         pops = []
         for text, timestamp in AntiSpam.tweet_store.items():
-            if now - timestamp > 600:
+            if now - timestamp > AntiSpam.timeout:
                 pops.append(text)
 
         for popper in pops:
@@ -77,6 +85,7 @@ def get_twit(func):
         """Instantiates a Twitter object based on streaming or RESTful."""
 
         settings = kwargs.get("settings", {})
+        _twit = None
 
         def _lookup_uid(twit):
             """Updates settings, adding the `uid` key."""
@@ -98,8 +107,11 @@ def get_twit(func):
                 settings["stream"] = False
                 if settings.get("user"):
                     _lookup_uid(twit)
-            kwargs.update({"twit": twit, "settings": settings})
+            _twit = twit
+        else:
+            _twit = kwargs["twit"]
 
+        kwargs.update({"twit": _twit, "settings": settings})
         return func(*args, **kwargs)
 
     return _get_twit
@@ -132,15 +144,16 @@ def _print_tweet(tweet, settings):
        AntiSpam.is_spam(tweet_text)):
         return False
 
-    for encoding in ["utf-8", "latin-1"]:
-        try:
-            tweet_text.decode(encoding)
-        except UnicodeEncodeError:
-            pass
+    if sys.version_info.major == 2:
+        for encoding in ["utf-8", "latin-1"]:
+            try:
+                tweet_text.decode(encoding)
+            except UnicodeEncodeError:
+                pass
+            else:
+                break
         else:
-            break
-    else:
-        return False
+            return False
 
     if settings.get("json"):
         print(json.dumps(tweet, indent=4, sort_keys=True))
